@@ -7,6 +7,4 @@ import "@jupyterlab/theme-light-extension"
 import "@phosphor/signaling"
 import "@phosphor/widgets"
 
-import '@jupyterlab/theme-light-extension/style/variables.css'
-import '@jupyterlab/codemirror/style/index.css';
-import '@jupyterlab/rendermime/style/index.css';
\ No newline at end of file
+import './jupyterlab-styles'
\ No newline at end of file
